@@ -161,12 +161,12 @@ static std::string toplist [] = {
     "    SEnd <n1> <n2>",       "send system effect to effect n1 at volume n2",
     "    (effect) <s>",         "the effect type",
     "    PREset <n>",           "set numbered effect preset to n",
-    "    -- ",                  "effect dependedent controls",
+    "    -- ",                  "effect dependent controls",
     "  INSert effects [n1]",    "enter effects context level",
     "    SEnd <s>/<n>",         "set where (Master, OFF or part number)",
     "    (effect) <s>",         "the effect type",
     "    PREset <n>",           "set numbered effect preset to n",
-    "    -- ",                  "effect dependedent controls",
+    "    -- ",                  "effect dependent controls",
     "  AVailable <n>",          "available parts (16, 32, 64)",
     "  PANning <n>",            "panning type (Cut, Default, Boost)",
     "  Volume <n>",             "master volume",
@@ -256,7 +256,7 @@ static std::string partlist [] = {
     "  Send <n1> <n2>",    "send part to system effect n1 at volume n2",
     "  (effect) <s>",      "the effect type",
     "  PREset <n>",        "set numbered effect preset to n",
-    "    -- ",             "effect dependedent controls",
+    "    -- ",             "effect dependent controls",
     "PRogram <s>/[s]<n>",  "loads instrument ID - CLear sets default,",
     "","Group n selects from group list",
     "LAtest",              "Show most recent bank load or save",
@@ -474,7 +474,7 @@ static std::string subsynthlist [] = {
     "Volume <n>",               "volume",
     "Pan <n>",                  "panning position",
     "PRandom <s>",              "enable random panning(ON, {other})",
-    "PRidth <n>",               "random panning range",
+    "PWidth <n>",               "random panning range",
     "VElocity <n>",             "velocity sensing sensitivity",
     "STEreo <s>",               "ON, {other}",
     "BENd Adjust <n>",          "pitch bend range",
@@ -858,7 +858,7 @@ static std::string learnlist [] = {
     "SEven",        "set incoming NRPNs as 7 bit (ON, {other})",
     "CC <n>",       "set incoming controller value",
     "CHan <n>",     "set incoming channel number",
-    "MIn <n>",      "set minimm percentage",
+    "MIn <n>",      "set minimum percentage",
     "MAx <n>",      "set maximum percentage",
     "LImit <s>",    "limit instead of compress (ON, {other})",
     "BLock <s>",    "inhibit others on this CC/Chan pair (ON, {other})",
