@@ -206,6 +206,10 @@ namespace TOPLEVEL // usage TOPLEVEL::section::vector
 
     enum control : unsigned char {
         // insert any new entries here
+
+        /*
+         * the following values must never appear in any other sections
+         */
         textMessage = 254, // FE
         forceExit // this is effective from *any* section!
     };
@@ -625,6 +629,9 @@ namespace PART // usage PART::control::volume
         midiFilterQ,
         midiFilterCutoff,
         midiBandwidth,
+        midiFMamp,
+        midiResonanceCenter,
+        midiResonanceBandwidth,
     // end of midi controls
 
         instrumentCopyright = 220,
